/* curs.c */
void	init_curs( void );
bool_t	init_curs_color( void );
bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n );
bool_t	chk_curs_draw( void );
void	ena_curs_draw( void );
void	dis_curs_draw( void );
bool_t	chk_curs( void );
void	ena_curs( void );
void	dis_curs( void );
void	curs_clearok( WINDOW *win, bool_t bf );
void	curs_initscr( void );
void	curs_endwin( void );
void	curs_keypad( WINDOW *win, bool_t bf );
void	curs_refresh( void );
curs_attr_t	get_current_attr( void );
void	curs_attrset_dflt( void );
void	curs_attrset_n( curs_attr_n_t n );
void	curs_attrset_dir( curs_attr_t *attr );
void	curs_attrset( int at );
void	curs_attron( int at );
void	curs_attroff( int at );
void	curs_echo( void );
void	curs_noecho( void );
void	curs_move( int scrn_y, int scrn_x );
void	curs_printw( char *s, ... );
void	curs_clear( void );
int	curs_getch( void );
void	curs_getnstr( char *s, int len );
curs_attr_t	*get_curs_attr( void );
bool_t	chk_color( void );
long	get_max_line( void );
